<?php

include_once( 'BingMapPro_LifeCycle.php');
include_once( 'BingMapPro_MasterMaps.php');

class BingMapPro_Plugin extends BingMapPro_LifeCycle{
    
    public function getPluginDisplayName(){
        return 'WP Bing Map Pro';
    }

    protected function getMainPluginFileName(){
        return 'wp-bing-map-pro.php';
    }

    protected function installDatabaseTables(){
      
        global $wpdb;
        $table_maps         = $this->prefixTableName('maps');
        $table_pins         = $this->prefixTableName('pins');
        $table_map_pins     = $this->prefixTableName('map_pins');
        $charset_collate    = $wpdb->get_charset_collate();
 
        $sql_bmp_maps =  "CREATE TABLE IF NOT EXISTS $table_maps (
                id mediumint(4) NOT NULL auto_increment,
                map_title varchar(100) NOT NULL default '',
                map_width varchar(5) NOT NULL default '100',
                map_height varchar(5) NOT NULL default '400',
                map_width_type varchar(5) NOT NULL default '%',
                map_height_type varchar(5) NOT NULL default 'px',
                map_start_lat varchar(100) NOT NULL default '53.350140',
                map_start_long varchar(100) NOT NULL default '-6.266155',
                map_zoom tinyint(3) NOT NULL default '2',
                map_type tinyint(1) NOT NULL default '0', 
                map_active boolean NOT NULL default '1',
                styling_json longtext default '',
                styling_enabled boolean NOT NULL default '0',
                alignment tinyint(5) default '0',
                kml longtext NOT NULL default '',
                html_class varchar(50) default '',
                map_disabled boolean NOT NULL default '0',
                map_shortcode varchar(100) default '',
                map_refresh boolean NOT NULL default '0',
                compact_nav boolean NOT NULL default '0',
                context_menu boolean NOT NULL default '0',
                show_pan_btns boolean NOT NULL default '0',
                look_at_location boolean NOT NULL default '0',
                bicycle boolean NOT NULL default '0',
                traffic boolean NOT NULL default '0',
                custom_map_style boolean NOT NULL default '0',                
                toggle_fullscreen boolean NOT NULL default '0',
                disable_mousewheel boolean NOT NULL default '0',
                disable_zoom boolean NOT NULL default '0',
                show_user_location boolean NOT NULL default '0',
                street_view boolean NOT NULL default '0',
                custom_map_style_script longtext,
                other_settings longtext NOT NULL default '',
                created_at datetime default '0000-00-00 00:00:00',
                PRIMARY KEY  (id),
                KEY map_active (map_active) 
                ) $charset_collate;
				";

        $sql_bmp_pins = "CREATE TABLE IF NOT EXISTS $table_pins ( 
                        id mediumint(4) NOT NULL auto_increment,                       
                        active boolean NOT NULL default '1',
                        pin_name varchar(255) NOT NULL default '',
                        pin_lat varchar(100) NOT NULL default '',
                        pin_long varchar(100) NOT NULL default '',
                        pin_address varchar(255) NOT NULL default '',                    
                        pin_title varchar(255) NOT NULL default '',
                        pin_desc text NOT NULL default '',
                        pin_custom_url varchar(255) NOT NULL default '',
                        pin_iframe_url varchar(255) NOT NULL default '',
                        pin_image_one varchar(255) NOT NULL default '',
                        pin_image_two varchar(255) NOT NULL default '',
                        pin_image_three varchar(255) NOT NULL default '',
                        pin_image_four varchar(255) NOT NULL default '',
                        pin_link_one varchar(255) NOT NULL default '',
                        pin_link_two varchar(255) NOT NULL default '',
                        pin_link_three varchar(255) NOT NULL default '',    
                        pin_link_four varchar(255) NOT NULL default '',
                        pin_link_one_txt varchar(50) NOT NULL default '',
                        pin_link_one_open varchar(10) NOT NULL default '',
                        pin_link_two_txt varchar(50) NOT NULL default '',
                        pin_link_two_open varchar(10) NOT NULL default '',
                        pin_link_three_txt varchar(50) NOT NULL default '',
                        pin_link_three_open varchar(10) NOT NULL default '',
                        pin_link_four_txt varchar(50) NOT NULL default '',
                        pin_link_four_open varchar(10) NOT NULL default '',
                        img_desc varchar(200) NOT NULL default '',
                        icon_link varchar(200) NOT NULL default '',
                        icon varchar(100) NOT NULL default '',
                        animation tinyint(1) NOT NULL default '0',
                        category tinyint(1) NOT NULL default '0',
                        pin_type tinyint(2) NOT NULL default '0',
                        direction_to_here boolean NOT NULL default '0',
                        data_json longtext NOT NULL default '',
                        other_settings text NOT NULL default '',
                        created_at datetime NOT NULL default '0000-00-00 00:00:00',
                        PRIMARY KEY  (id)
                    ) $charset_collate;
					";
    
        $sql_bmp_map_pins = "CREATE TABLE IF NOT EXISTS $table_map_pins( 
                        id mediumint(4) NOT NULL auto_increment,
                        map_id mediumint(4) NOT NULL default '0',
                        pin_id mediumint(4) NOT NULL default '0',
                        pin_active boolean NOT NULL default '1',
                        created_at datetime NOT NULL default '0000-00-00 00:00:00',
                        PRIMARY KEY  (id),
                        KEY map_id (map_id),
                        KEY pin_id (pin_id),
                        KEY pin_active (pin_active)
                    ) $charset_collate;
                    ";


        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta( $sql_bmp_maps ); 
        dbDelta( $sql_bmp_pins ); 
        dbDelta( $sql_bmp_map_pins );               
    }

    protected function uninstallDatabaseTables(){
        //        global $wpdb;
        //        $tableName = $this->prefixTableName('mytable');
        //        $wpdb->query("DROP TABLE IF EXISTS `$tableName`");
    }

    public function upgrade(){

    }

    public function addActionsAndFilters(){

        add_action('admin_menu', array(&$this, 'addSettingsSubMenuPage'));      

  
        add_action( 'wp_ajax_bmp_general_settings', array( &$this,  'bmp_general_settings' ) );

        add_action( 'wp_ajax_bmp_map_actions', array( &$this, 'bmp_map_actions') );

    //  save map async
        add_action( 'wp_ajax_bmp_save_map', array( &$this, 'bmp_save_map') );

        add_action('admin_enqueue_scripts', array( &$this, 'pw_load_scripts')); 

        add_action('activated_plugin',array( &$this, 'my_save_error') ); 
        
        add_action('wp_ajax_bmp_new_pin', array( &$this, 'bmp_new_pin') );

        add_action('wp_ajax_bmp_pin_actions', array( &$this, 'bmp_pin_actions') );

        add_action('init', array(&$this, 'bmp_shortcodes_init'));

    }


    public function pw_load_scripts( $hook ){
        global $pw_settings_page;
        global $pw_main_page;
        global $pw_settings_pins;

        if( ( $pw_settings_page != $hook) && ($hook != $pw_main_page) && ( $hook != $pw_settings_pins) )
            return;

        wp_enqueue_script('my-script-jquery', includes_url('js/jquery/jquery.js', __FILE__ ) );
        wp_enqueue_style('my-style-bootstrap-bmp', plugins_url('/css/bootstrap.css' . '?v='.$this->getVersion(), __FILE__) );
        wp_enqueue_style('my-style-fontawsome-bmp', plugins_url('/css/fa/css/all.css'.'?v='.$this->getVersion(), __FILE__));
        wp_enqueue_style('my-style-bootstrap-toggle', plugins_url('/css/bootstrap-toggle.min.css'. '?v='.$this->getVersion(), __FILE__ ));
        wp_enqueue_style('bmp-style', plugins_url('/css/bmp-style.css' . '?ver='.$this->getVersion(), __FILE__ ));
        
        wp_enqueue_script('my_script_bootstrap-toggle', plugins_url('/js/bootstrap-toggle.min.js' . '?v='.$this->getVersion(), __FILE__ ));
        wp_enqueue_script('my-script-bootstrap', plugins_url('/js/bootstrap.min.js' . '?v='.$this->getVersion(), __FILE__));        
        wp_enqueue_script('my-script-bmp', plugins_url('/js/bmp-script.js'.'?v=' . $this->getVersion(), __FILE__ ));
        wp_enqueue_script('bmp-script-ajax',  plugins_url('/js/bmp-script-ajax.js'.'?v=' . $this->getVersion(), __FILE__ ));

        if( $hook == $pw_settings_pins ){
            wp_enqueue_script('my-script-bmp-pins', plugins_url('/js/bmp-script-pins.js'.'?v=' . $this->getVersion(), __FILE__ ));   
        }
    }
}
?>